==> jc-1.4.0.tar.gz: polyglot/ext/jl/Version.h <==
// public class polyglot.ext.jl.Version

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fb81e052aafe4b1f polyglot_ext_jl_Version
// @dep_class 4ba1325a7aefecac polyglot_main_Version

// header file dependencies
// @dep_header polyglot_main_Version

#include "polyglot/main/Version.h"

#ifndef _JC_polyglot_ext_jl_Version_H_
#define _JC_polyglot_ext_jl_Version_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_Version$sub_refs	_jc_polyglot_ext_jl_Version$sub_refs;
typedef struct _jc_polyglot_ext_jl_Version$sub_nonrefs	_jc_polyglot_ext_jl_Version$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_Version$refs	_jc_polyglot_ext_jl_Version$refs;
typedef struct _jc_polyglot_ext_jl_Version$nonrefs	_jc_polyglot_ext_jl_Version$nonrefs;
typedef struct _jc_polyglot_ext_jl_Version$object	_jc_polyglot_ext_jl_Version$object;

typedef const struct _jc_polyglot_ext_jl_Version$vmethods	_jc_polyglot_ext_jl_Version$vmethods;
typedef const struct _jc_polyglot_ext_jl_Version$vtable	_jc_polyglot_ext_jl_Version$vtable;
typedef const struct _jc_polyglot_ext_jl_Version$vtype	_jc_polyglot_ext_jl_Version$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);

// Virtual methods
extern jint _jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
extern jint _jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
extern jint _jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_Version$vmethods {
	jint	(*major$11e120a477900a2f)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
	jint	(*minor$206704e7c95168d6)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
	jint	(*patch__5flevel$c3db817585344b9f)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_Version$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Version$vmethods	polyglot_main_Version;
	_jc_polyglot_ext_jl_Version$vmethods	polyglot_ext_jl_Version;
};

// Vtype
struct _jc_polyglot_ext_jl_Version$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_Version$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_Version$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_Version$refs {
    _jc_polyglot_ext_jl_Version$sub_refs	polyglot_ext_jl_Version;
    _jc_polyglot_main_Version$sub_refs	polyglot_main_Version;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_Version$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_Version$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Version$sub_nonrefs	polyglot_main_Version;
    _jc_polyglot_ext_jl_Version$sub_nonrefs	polyglot_ext_jl_Version;
};

// Object instance structure
struct _jc_polyglot_ext_jl_Version$object {
	_jc_polyglot_ext_jl_Version$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_Version$vtype	*vtype;
	_jc_polyglot_ext_jl_Version$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_Version$vtype _jc_polyglot_ext_jl_Version$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_Version, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_Version$class_object;

#endif	/* _JC_polyglot_ext_jl_Version_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/Version.h <==
// public class polyglot.ext.jl.Version

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fb81e052aafe4b1f polyglot_ext_jl_Version
// @dep_class 4ba1325a7aefecac polyglot_main_Version

// header file dependencies
// @dep_header polyglot_main_Version

#include "polyglot/main/Version.h"

#ifndef _JC_polyglot_ext_jl_Version_H_
#define _JC_polyglot_ext_jl_Version_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_Version$sub_refs	_jc_polyglot_ext_jl_Version$sub_refs;
typedef struct _jc_polyglot_ext_jl_Version$sub_nonrefs	_jc_polyglot_ext_jl_Version$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_Version$refs	_jc_polyglot_ext_jl_Version$refs;
typedef struct _jc_polyglot_ext_jl_Version$nonrefs	_jc_polyglot_ext_jl_Version$nonrefs;
typedef struct _jc_polyglot_ext_jl_Version$object	_jc_polyglot_ext_jl_Version$object;

typedef const struct _jc_polyglot_ext_jl_Version$vmethods	_jc_polyglot_ext_jl_Version$vmethods;
typedef const struct _jc_polyglot_ext_jl_Version$vtable	_jc_polyglot_ext_jl_Version$vtable;
typedef const struct _jc_polyglot_ext_jl_Version$vtype	_jc_polyglot_ext_jl_Version$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_Version$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_polyglot_ext_jl_Version$method$major$11e120a477900a2f(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_ext_jl_Version$method$minor$206704e7c95168d6(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_Version$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_ext_jl_Version$method$patch__5flevel$c3db817585344b9f(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$major$11e120a477900a2f;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$minor$206704e7c95168d6;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$name$e6acce026cadf81e;
extern _jc_method _jc_polyglot_ext_jl_Version$method_info$patch__5flevel$c3db817585344b9f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_Version$vmethods {
	jint	(*major$11e120a477900a2f)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
	jint	(*minor$206704e7c95168d6)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
	jint	(*patch__5flevel$c3db817585344b9f)(_jc_env *, struct _jc_polyglot_ext_jl_Version$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_Version$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Version$vmethods	polyglot_main_Version;
	_jc_polyglot_ext_jl_Version$vmethods	polyglot_ext_jl_Version;
};

// Vtype
struct _jc_polyglot_ext_jl_Version$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_Version$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_Version$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_Version$refs {
    _jc_polyglot_ext_jl_Version$sub_refs	polyglot_ext_jl_Version;
    _jc_polyglot_main_Version$sub_refs	polyglot_main_Version;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_Version$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_Version$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Version$sub_nonrefs	polyglot_main_Version;
    _jc_polyglot_ext_jl_Version$sub_nonrefs	polyglot_ext_jl_Version;
};

// Object instance structure
struct _jc_polyglot_ext_jl_Version$object {
	_jc_polyglot_ext_jl_Version$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_Version$vtype	*vtype;
	_jc_polyglot_ext_jl_Version$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_Version$vtype _jc_polyglot_ext_jl_Version$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_Version, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_Version$class_object;

#endif	/* _JC_polyglot_ext_jl_Version_H_ */
